#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_FIRST_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_FIRST_HPP_INCLUDED

#include <nt2/swar/include/functions/scalar/interleave_first.hpp>

#endif
